@@ -8,6 +8,7 @@ type configT struct {
 	PluginDir     string `yaml:"pluginDir"`
 	LogLevel      string `yaml:"logLevel" validate:"oneof=error warn info debug"`
 	HandlerErrors bool   `yaml:"handleErrors"`
+	BlockEventBus bool   `yaml:"blockEventBus"`
 	Transports    []struct {
 		Name     string `validate:"required"`
 		Handlers []struct {
@@ -31,4 +32,5 @@ var configuration = configT{
 	PluginDir:     "/usr/lib64/sg-core/",
 	LogLevel:      "info",
 	HandlerErrors: false,
+	BlockEventBus: false,
 }
