@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/infrawatch/apputils/connector"
+	"github.com/infrawatch/apputils/connector/loki"
 	"github.com/infrawatch/apputils/misc"
 
 	"github.com/infrawatch/sg-core/pkg/data"
@@ -21,16 +21,16 @@ func createLabels(rawLabels map[string]interface{}) (map[string]string, error) {
 }
 
 // CreateLokiLog forms event to a structure suitable for storage in Loki
-func CreateLokiLog(log data.Event) (connector.LokiLog, error) {
+func CreateLokiLog(log data.Event) (loki.LokiLog, error) {
 	labels, err := createLabels(log.Labels)
 	if err != nil {
-		return connector.LokiLog{}, err
+		return loki.LokiLog{}, err
 	}
 
 	// correct severity value in labels
 	labels["severity"] = log.Severity.String()
 
-	output := connector.LokiLog{
+	output := loki.LokiLog{
 		LogMessage: log.Message,
 		Timestamp:  time.Duration(log.Time) * time.Second,
 		Labels:     labels,
